import { SvelteComponent } from "svelte";
export declare function getGridContext(): Readable<GridParams>;
import type { Breakpoints, ItemSize, GridSize, LayoutChangeDetail, GridParams, Collision, GridController as GridControllerType } from './types';
import { type Readable } from 'svelte/store';
declare const __propDef: {
    props: {
        /**
             * Number of columns in the grid.
             */ cols?: GridSize | undefined;
        /**
             * Number of rows in the grid.
             */ rows?: GridSize | undefined;
        /**
             * Size of the grid items.
             * @description
             * If not provided, the grid will try to calculate the size based on the container size.
             *
             * You can provide only one of the dimensions, the other will be calculated automatically or you can provide both.
             * @example
             * ```svelte
             * <Grid itemSize={{ width: 100, height: 100 }}>
             * <Grid itemSize={{ width: 100}}>
             * ```
             */ itemSize?: Partial<ItemSize> | undefined;
        /**
             * Gap between the grid items.
             */ gap?: number | undefined;
        /**
             * Breakpoints for the grid. That will be used to calculate the grid size.
             *
             * Important: numbers represent container width NOT document width.
             * @example
             * ```svelte
             * <Grid breakpoints={{ xs: 320, sm: 640, md: 768, lg: 1024, xl: 1280, xxl: 1536 }}>
             * ```
             */ breakpoints?: Breakpoints | undefined;
        /**
             * Bound the grid items to the grid container.
             */ bounds?: boolean | undefined;
        /**
             * Disable the items interaction.
             */ readOnly?: boolean | undefined;
        /**
             * Enable the grid debug mode.
             * WIP
             */ debug?: boolean | undefined;
        /**
             * Grid container class.
             */ class?: string | undefined;
        /**
             * This option set the collision strategy between grid items. If is not 'none' then it sets 'rows' option to 0.
             */ collision?: Collision | undefined;
        /**
             * Auto compress the grid items when programmatically changing grid items.
             * Only works with 'compress' collision strategy.
             * @default true
             */ autoCompress?: boolean | undefined;
        controller?: GridControllerType | undefined;
    };
    events: {
        change: CustomEvent<LayoutChangeDetail>;
    } & {
        [evt: string]: CustomEvent<any>;
    };
    slots: {
        default: {};
    };
};
export type GridProps = typeof __propDef.props;
export type GridEvents = typeof __propDef.events;
export type GridSlots = typeof __propDef.slots;
export default class Grid extends SvelteComponent<GridProps, GridEvents, GridSlots> {
    get controller(): GridControllerType;
}
export {};
