import { getAvailablePosition, hasCollisions } from './utils/grid';
export class GridController {
    gridParams;
    constructor(gridParams) {
        this.gridParams = gridParams;
    }
    getFirstAvailablePosition(w, h) {
        const { items, maxCols, maxRows } = this.gridParams;
        return getAvailablePosition({
            id: '',
            x: 0,
            y: 0,
            w,
            h,
            movable: true,
            resizable: true,
            invalidate: () => {
                /* .. */
            }
        }, Object.values(items), maxCols, maxRows);
    }
    compress() {
        this._compress(this.gridParams.items);
    }
    _internalCompress() {
        this._compress(this.gridParams.items, true);
    }
    _compress(items, skipUpdate = false) {
        const gridItems = Object.values(items);
        const sortedItems = [...gridItems].sort((a, b) => a.y - b.y);
        sortedItems.reduce((accItem, currentItem) => {
            let newY = currentItem.y;
            while (newY >= 0) {
                if (hasCollisions({ ...currentItem, y: newY }, accItem)) {
                    break;
                }
                newY--;
            }
            if (newY !== currentItem.y - 1) {
                currentItem.y = newY + 1;
                currentItem.invalidate();
            }
            accItem.push(currentItem);
            return accItem;
        }, []);
        if (!skipUpdate) {
            this.gridParams.updateGrid();
        }
    }
}
